/* 
 * Based on f2a by Ulrich Hecht <uli@emulinks.de>
 * if2a by D. Gauchard <deyv@free.fr>
 * F2A Ultra support by Vincent Rubiolo <vincent.rubiolo@free.fr>
 * Licensed under the terms of the GNU Public License version 2
 */

#include <string.h>
#include <ctype.h>

#include "../../libf2a.h"
#include "../../binware.h"
#include "../../cartutils.h"
#include "f2amisc.h"

int conv_f2apro_bank (const char* bank, int* offset, int* size)
{
	int len = strlen(bank);

	if (len > 3)
		return -1;

	if (strcmp(bank, "all") == 0 || bank[0] == 0)
	{
		*offset = 0;
		*size = 256 << 10;
	}
	else
	{
		*offset = (bank[0] - '1') << 16;
		if (bank[1])
		{
			*offset += (tolower(bank[1]) - 'a') << 15;
			
			if (bank[2])
			{
				*offset += (bank[2] - '1') << 13;
				*size = 1 << 13;
			}
			else
				*size = 1 << 15;
		}
		else
			*size = 1 << 16;
	}
	if (cart_verbose && bank[0])
		print("Bank '%s' is SRAM is (offset=0x%x/%ibytes size=0x%x/%ibytes)\n",
			bank, *offset, *offset, *size, *size);
	return 0;
}

int select_f2a_loader (cart_type_e cart_type, const char* loader_file)
{
	int result = -1;

	if (loader.size == 0)
	{
		switch (cart_type)
		{
			case CART_TYPE_F2A_PRO:
				result = binware_load(&loader, binware_f2a_loader_pro, loader_file, "F2A-PRO-loader");
				break;
			case CART_TYPE_F2A_ULTRA:
				result = binware_load(&loader, binware_f2a_loader_ultra, loader_file, "F2A-Ultra-loader");
				break;
			case CART_TYPE_F2A_TURBO:
				printerr("looking for TURBO cart testers - assuming PRO - please contact us at if2a@ml.free.fr\n");
				result = binware_load(&loader, binware_f2a_loader_pro, loader_file, "F2A-Turbo-loader");
				break;
			default:
				printerr("Undefined F2A cart type, please use -t\n");
				result = -1;
				break;
		}
		return result;
	}
	else
		return 0;
}

int select_f2a_firmware (const char* name)
{
	return binware_load(&firmware, binware_f2a_usb_firmware, name, "F2A-usb-linker-firmware");
}

int select_f2a_linker_multiboot (const char* name)
{
	return binware_load(&multiboot, binware_f2a_multiboot, name, "F2A-usb-linker-multiboot");
}

int select_f2a_splash (const char* name)
{
	return binware_load(&splash, binware_f2a_splash, name, "F2A-splash");
}
